package marker;

import minidraw.standard.*;
import minidraw.framework.*;

import rect.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/** Demonstrate MiniDraw Observer ability.
 * Demonstrates:
 * A) Register to listen to FigureChangeEvents
 * B) Make a figure react upon events
 * C) Use of Decorator to implement this behavior
 *
 * Move the AU seal using the mouse, and uses the
 * FigureChange Observer pattern mechanisms of MiniDraw
 * to make the two arrows always point to the logo.
*/

public class Markers {
  public static void main(String[] args) {
    Factory f = new EmptyCanvasFactory();
    DrawingEditor editor = 
      new MiniDrawApplication( "Markers - move the white seal", f );

    editor.open();
    Figure logo = new ImageFigure( "au-seal-small", new Point(200, 200));

    Figure rightArrow = 
      new MarkerFigureDecorator( new ImageFigure( "arrow-right", 
                                                  new Point(0, 200)),
                                 logo,
                                 false );
    Figure downArrow = 
      new MarkerFigureDecorator( new ImageFigure( "arrow-down", 
                                                  new Point(200, 0)),
                                 logo,
                                 true );

    editor.setTool( new SelectionTool(editor) );

    editor.drawing().add(rightArrow);
    editor.drawing().add(downArrow);
    editor.drawing().add(logo);
  }
}

class EmptyCanvasFactory implements Factory {

  public DrawingView createDrawingView( DrawingEditor editor ) {
    return new StandardDrawingView(editor);
  }

  public Drawing createDrawing( DrawingEditor editor ) {
    return new StandardDrawing();
  }

  public JTextField createStatusField( DrawingEditor editor ) {
    return null;
  }
}
