import sys
sys.path.append("minidrawmod.jar")

from minidraw.framework import Factory, Figure, FigureChangeListener
from minidraw.standard import (MiniDrawApplication, StandardDrawing,
                               StandardDrawingView, ImageFigure, SelectionTool)
from java.awt import Point

def main():
    editor = MiniDrawApplication("Markers - move the white seal",
                                 EmptyCanvasFactory())
    editor.open()

    logo = ImageFigure("au-seal-small", Point(200,200))
    rightArrow = MarkerFigureDecorator(ImageFigure("arrow-right", Point(0,200)),
                                       logo, False)
    
    downArrow = MarkerFigureDecorator(ImageFigure("arrow-down", Point(200,0)),
                                      logo, True)

    editor.setTool(SelectionTool(editor))

    editor.drawing().add(rightArrow)
    editor.drawing().add(downArrow)
    editor.drawing().add(logo)

    
class EmptyCanvasFactory(Factory):

    def createDrawingView(self, editor):
        return StandardDrawingView(editor)

    def createDrawing(self, editor):
        return StandardDrawing()


class MarkerFigureDecorator(Figure):

    def __init__(self, decoratee, target, horizontal):
        self.decoratee = decoratee
        self.horizontal = horizontal
        target.addFigureChangeListener(Observer(decoratee, horizontal))

    def draw(self, g): self.decoratee.draw(g)
    def displayBox(self): return self.decoratee.displayBox()
    def moveBy(self,x,y): self.decoratee.moveby(x,y)
    def invalidate(self): self.decoratee.invalidate()
    def changed(self): self.decoratee.changed()
    def addFigureChangeListener(self, x):
        self.decoratee.addFigureChangeListener(x)
    def removeFigureChangelistener(self, x):
        self.decoratee.removeFigureChangeListener(x)

        
class Observer(FigureChangeListener):

    def __init__(self, follower, horizontal):
        self.follower = follower
        self.horizontal = horizontal

    def figureChanged(self, e):
        target_r = e.getFigure().displayBox()
        marker_r = self.follower.displayBox()
        dx,dy = 0,0
        if self.horizontal:
            dx = target_r.x - marker_r.x
        else:
            dy = target_r.y - marker_r.y
        self.follower.moveBy(dx,dy)

main()
