import sys
sys.path.append("minidrawmod.jar")

from minidraw.framework import Factory, Figure, FigureChangeListener
from minidraw.standard import (MiniDrawApplication, StandardDrawing,
                               StandardDrawingView, ImageFigure, SelectionTool)
from java.awt import Point

def main():
    editor = MiniDrawApplication("Markers - move the white seal",
                                 EmptyCanvasFactory())
    editor.open()

    logo = ImageFigure("au-seal-small", Point(200,200))

    rightArrow = ImageFigure("arrow-right", Point(0,200))
    # set rightArrow to track logo vertically
    logo.addFigureChangeListener(PositionMarker(follower=rightArrow,
                                                horizontal=False))

    downArrow = ImageFigure("arrow-down", Point(200,0))
    # set downArrow to track logo horizontally
    logo.addFigureChangeListener(PositionMarker(follower=downArrow,
                                                horizontal=True))

    editor.setTool(SelectionTool(editor))

    editor.drawing().add(rightArrow)
    editor.drawing().add(downArrow)
    editor.drawing().add(logo)


class EmptyCanvasFactory(Factory):

    def createDrawingView(self, editor):
        return StandardDrawingView(editor)

    def createDrawing(self, editor):
        return StandardDrawing()


class PositionMarker(FigureChangeListener):

    def __init__(self, follower, horizontal):
        self.follower = follower
        self.horizontal = horizontal

    def figureChanged(self, e):
        target_r = e.getFigure().displayBox()
        marker_r = self.follower.displayBox()
        dx,dy = 0,0
        if self.horizontal:
            dx = target_r.x - marker_r.x
        else:
            dy = target_r.y - marker_r.y
        self.follower.moveBy(dx,dy)

    
main()        
    

    
