import sys
sys.path.append("minidrawmod.jar")

from minidraw.standard import *
from minidraw.framework import *

from java.awt import *
from java.awt.event import *
from javax.swing import *

def main():
    f = emptyCanvasFactory()
    editor = MiniDrawApplication("Create and move rectangles - use the mouse", f)
    rectangleDrawTool = RectangleTool(editor)
    selectionTool = SelectionTool(editor)
    addToolSelectMenusToWindow(editor, rectangleDrawTool, selectionTool)
    editor.open()
    editor.setTool(rectangleDrawTool)
    editor.showStatus(" MiniDraw version: "+DrawingEditor.VERSION)

    newWindow = JFrame("Extra View")
    newWindow.setLocation(620, 20)
    newWindow.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE)

    extraView = f.createDrawingView(editor)
    panel = extraView
    newWindow.getContentPane().add(panel)
    newWindow.pack()
    newWindow.setVisible(True)


def addToolSelectMenusToWindow(window, rectangleTool, selectionTool):
    menuBar = JMenuBar()
    menu = JMenu("Tool")
    menuBar.add(menu)

    def activateRectangleTool(e):
        window.setTool(rectangleTool)
        window.showStatus("Rectangle tool active")

    menu.add(JMenuItem("Rectangle", actionPerformed=activateRectangleTool))

    def activateSelectionTool(e):
        window.setTool(selectionTool)
        window.showStatus("Selection tool active")

    menu.add(JMenuItem("Selection", actionPerformed=activateSelectionTool))
    window.setJMenuBar(menuBar)


class emptyCanvasFactory(Factory):

    def createDrawingView(self, editor):
        return StandardDrawingView(editor, Dimension(400,200))

    def createDrawing(self, editor):
        return StandardDrawing()

    def createStatusField(self, editor):
        return JTextField()


class RectangleTool(AbstractTool):

    def __init__(self, editor):
        AbstractTool.__init__(self, editor)
        self.f = None

    def mouseDown(self, e, x, y):
        self.fAnchorX = x
        self.fAnchorY = y
        self.f = RectangleFigure(Point(x,y))
        self.editor().drawing().add(self.f)

    def mouseDrag(self, e, x, y):
        self.f.resize(Point(self.fAnchorX, self.fAnchorY), Point(x,y))

    def mouseUp(self, e, x, y):
        if self.f.displayBox().isEmpty():
            self.editor().drawing().remove(self.f)
        self.f = None


class RectangleFigure(AbstractFigure):

    def __init__(self, origin, corner=None, color=Color.GREEN):
        if corner is None:
            corner = origin
        self.basicResize(origin, corner)
        self.color = color

    def basicResize(self, origin, corner):
        self.fDisplayBox = Rectangle(origin)
        self.fDisplayBox.add(corner)

    def displayBox(self):
        fdb = self.fDisplayBox
        return Rectangle(fdb.x, fdb.y, fdb.width, fdb.height)

    def basicMoveBy(self, x,y):
        self.fDisplayBox.translate(x,y)

    def resize(self, origin, corner):
        self.willChange()
        self.basicResize(origin, corner)
        self.changed()

    def draw(self, g):
        r = self.displayBox()
        g.setColor(self.color)
        g.fillRect(r.x, r.y, r.width, r.height)
        g.setColor(Color.BLACK)
        g.drawRect(r.x, r.y, r.width-1, r.height-1)


main()
